==> molview_messages-0.4.0.tar.gz: lib/src/dataserver/record.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.dataserver;

/// Data record
class DataRecord {
  /// Keys by their index in [DataTable.keys]
  final Map<int, dynamic> keys;

  /// Values by their index in [DataTable.values]
  final Map<int, dynamic> values;

  /// Parameters that were used to retrieve this record.
  final Map<String, String> parameters;

  /// Constructor
  DataRecord(this.keys, this.values, this.parameters);

  /// Construct from JSON data.
  factory DataRecord.fromJson(Map<String, dynamic> data) {
    return new DataRecord(
        _generateIntMap(data['keys'] as Map<String, dynamic>),
        _generateIntMap(data['values'] as Map<String, dynamic>),
        data['parameters'] as Map<String, String>);
  }

  /// Convert to JSON compatible data.
  Map<String, dynamic> toJson() {
    return {
      'keys': _generateStringMap(keys),
      'values': _generateStringMap(values),
      'parameters': parameters,
    };
  }
}

/// Generate integer indexed map from string indexed map.
Map<int, dynamic> _generateIntMap(Map<String, dynamic> input) {
  var output = new Map<int, dynamic>();
  input.forEach((String key, dynamic value) =>
      output.putIfAbsent(int.parse(key), () => value));
  return output;
}

/// Generate string indexed map from integer indexed map.
Map<String, dynamic> _generateStringMap(Map<int, dynamic> input) {
  var output = new Map<String, dynamic>();
  input.forEach((int key, dynamic value) =>
      output.putIfAbsent(key.toString(), () => value));
  return output;
}

==> molview_messages-0.4.1.tar.gz: lib/src/dataserver/record.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.dataserver;

/// Data record
class DataRecord {
  /// Keys by their index in [DataTable.keys]
  final Map<int, dynamic> keys;

  /// Values by their index in [DataTable.values]
  final Map<int, dynamic> values;

  /// Parameters that were used to retrieve this record.
  final Map<String, String> parameters;

  /// Constructor
  DataRecord(this.keys, this.values, this.parameters);

  /// Construct from PDS.
  factory DataRecord.fromPds(Map<String, dynamic> data) {
    return new DataRecord(
        _generateIntMap(data['keys'] as Map<String, dynamic>),
        _generateIntMap(data['values'] as Map<String, dynamic>),
        data['parameters'] as Map<String, String>);
  }

  /// Convert to PDS.
  Map<String, dynamic> toPds() {
    return {
      'keys': _generateStringMap(keys),
      'values': _generateStringMap(values),
      'parameters': parameters,
    };
  }
}

/// Generate integer indexed map from string indexed map.
Map<int, dynamic> _generateIntMap(Map<String, dynamic> input) {
  var output = new Map<int, dynamic>();
  input.forEach((String key, dynamic value) =>
      output.putIfAbsent(int.parse(key), () => value));
  return output;
}

/// Generate string indexed map from integer indexed map.
Map<String, dynamic> _generateStringMap(Map<int, dynamic> input) {
  var output = new Map<String, dynamic>();
  input.forEach((int key, dynamic value) =>
      output.putIfAbsent(key.toString(), () => value));
  return output;
}
